==> webkit2gtk_2.20.1.orig.tar.xz: webkitgtk-2.20.1/Tools/TestWebKitAPI/Tests/WebCore/StringWithDirection.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include "Test.h"
#include "WTFStringUtilities.h"
#include <WebCore/StringWithDirection.h>

using namespace WebCore;

namespace TestWebKitAPI {

TEST(StringWithDirection, TruncateAtEndWithLeftToRightString)
{
    StringWithDirection string { "Cappuccino", LTR };
    StringWithDirection result;

    result = truncateFromEnd(string, 0);
    EXPECT_EQ(LTR, result.direction);
    EXPECT_EQ("", result.string);

    result = truncateFromEnd(string, 1);
    EXPECT_EQ(LTR, result.direction);
    EXPECT_EQ("C", result.string);

    result = truncateFromEnd(string, 2);
    EXPECT_EQ(LTR, result.direction);
    EXPECT_EQ("Ca", result.string);

    result = truncateFromEnd(string, 1000);
    EXPECT_EQ(LTR, result.direction);
    EXPECT_EQ("Cappuccino", result.string);
}

TEST(StringWithDirection, TruncateAtEndWithRightToLeftString)
{
    StringWithDirection string { String::fromUTF8("קָפּוּצִ'ינוֹ"), RTL };
    StringWithDirection result;

    result = truncateFromEnd(string, 0);
    EXPECT_EQ(RTL, result.direction);
    EXPECT_EQ("", result.string);

    result = truncateFromEnd(string, 1);
    EXPECT_EQ(RTL, result.direction);
    EXPECT_EQ(String::fromUTF8("ק"), result.string);

    result = truncateFromEnd(string, 2);
    EXPECT_EQ(RTL, result.direction);
    EXPECT_EQ(String::fromUTF8("קָ"), result.string);

    result = truncateFromEnd(string, 1000);
    EXPECT_EQ(RTL, result.direction);
    EXPECT_EQ(String::fromUTF8("קָפּוּצִ'ינוֹ"), result.string);
}

} // namespace TestWebKitAPI

==> webkit2gtk_2.38.3.orig.tar.xz: webkitgtk-2.38.3/Tools/TestWebKitAPI/Tests/WebCore/StringWithDirection.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include "Test.h"
#include "WTFStringUtilities.h"
#include <WebCore/StringWithDirection.h>

using namespace WebCore;

namespace WebCore {

std::ostream& operator<<(std::ostream& os, const TextDirection& direction)
{
    switch (direction) {
    case TextDirection::LTR:
        os << "TextDirection::LTR";
        break;
    case TextDirection::RTL:
        os << "TextDirection::RTL";
        break;
    }
    return os;
}

}

namespace TestWebKitAPI {

TEST(StringWithDirection, TruncateAtEndWithLeftToRightString)
{
    StringWithDirection string { "Cappuccino"_s, TextDirection::LTR };
    StringWithDirection result;

    result = truncateFromEnd(string, 0);
    EXPECT_EQ(TextDirection::LTR, result.direction);
    EXPECT_EQ(""_s, result.string);

    result = truncateFromEnd(string, 1);
    EXPECT_EQ(TextDirection::LTR, result.direction);
    EXPECT_EQ("C"_s, result.string);

    result = truncateFromEnd(string, 2);
    EXPECT_EQ(TextDirection::LTR, result.direction);
    EXPECT_EQ("Ca"_s, result.string);

    result = truncateFromEnd(string, 1000);
    EXPECT_EQ(TextDirection::LTR, result.direction);
    EXPECT_EQ("Cappuccino"_s, result.string);
}

TEST(StringWithDirection, TruncateAtEndWithRightToLeftString)
{
    StringWithDirection string { String::fromUTF8("קָפּוּצִ'ינוֹ"), TextDirection::RTL };
    StringWithDirection result;

    result = truncateFromEnd(string, 0);
    EXPECT_EQ(TextDirection::RTL, result.direction);
    EXPECT_EQ(""_s, result.string);

    result = truncateFromEnd(string, 1);
    EXPECT_EQ(TextDirection::RTL, result.direction);
    EXPECT_EQ(String::fromUTF8("ק"), result.string);

    result = truncateFromEnd(string, 2);
    EXPECT_EQ(TextDirection::RTL, result.direction);
    EXPECT_EQ(String::fromUTF8("קָ"), result.string);

    result = truncateFromEnd(string, 1000);
    EXPECT_EQ(TextDirection::RTL, result.direction);
    EXPECT_EQ(String::fromUTF8("קָפּוּצִ'ינוֹ"), result.string);
}

} // namespace TestWebKitAPI
